bool module_african (struct recode_outer *);
bool module_afrtran (struct recode_outer *);
bool module_atarist (struct recode_outer *);
bool module_bangbang (struct recode_outer *);
bool module_cdcnos (struct recode_outer *);
bool module_ebcdic (struct recode_outer *);
bool module_ibmpc (struct recode_outer *);
bool module_iconqnx (struct recode_outer *);
bool module_latin1_ascii (struct recode_outer *);
bool module_latin1_iso5426 (struct recode_outer *);
bool module_latin1_ansel (struct recode_outer *);
bool module_java (struct recode_outer *);
bool module_mule (struct recode_outer *);
bool module_strips (struct recode_outer *);
bool module_testdump (struct recode_outer *);
bool module_ucs (struct recode_outer *);
bool module_utf16 (struct recode_outer *);
bool module_utf7 (struct recode_outer *);
bool module_utf8 (struct recode_outer *);
bool module_varia (struct recode_outer *);
bool module_vietnamese (struct recode_outer *);
bool module_flat (struct recode_outer *);
bool module_html (struct recode_outer *);
bool module_latin1_latex (struct recode_outer *);
bool module_latin1_bibtex (struct recode_outer *);
bool module_latin1_texte (struct recode_outer *);
bool module_rfc1345 (struct recode_outer *);
bool module_texinfo (struct recode_outer *);
bool module_base64 (struct recode_outer *);
bool module_dump (struct recode_outer *);
bool module_endline (struct recode_outer *);
bool module_permutations (struct recode_outer *);
bool module_quoted_printable (struct recode_outer *);
bool module_ascii_latin1 (struct recode_outer *);
bool module_iso5426_latin1 (struct recode_outer *);
bool module_ansel_latin1 (struct recode_outer *);
bool module_latex_latin1 (struct recode_outer *);
bool module_bibtex_latin1 (struct recode_outer *);
bool module_texte_latin1 (struct recode_outer *);
void delmodule_african (struct recode_outer *);
void delmodule_afrtran (struct recode_outer *);
void delmodule_atarist (struct recode_outer *);
void delmodule_bangbang (struct recode_outer *);
void delmodule_cdcnos (struct recode_outer *);
void delmodule_ebcdic (struct recode_outer *);
void delmodule_ibmpc (struct recode_outer *);
void delmodule_iconqnx (struct recode_outer *);
void delmodule_latin1_ascii (struct recode_outer *);
void delmodule_latin1_iso5426 (struct recode_outer *);
void delmodule_latin1_ansel (struct recode_outer *);
void delmodule_java (struct recode_outer *);
void delmodule_mule (struct recode_outer *);
void delmodule_strips (struct recode_outer *);
void delmodule_testdump (struct recode_outer *);
void delmodule_ucs (struct recode_outer *);
void delmodule_utf16 (struct recode_outer *);
void delmodule_utf7 (struct recode_outer *);
void delmodule_utf8 (struct recode_outer *);
void delmodule_varia (struct recode_outer *);
void delmodule_vietnamese (struct recode_outer *);
void delmodule_flat (struct recode_outer *);
void delmodule_html (struct recode_outer *);
void delmodule_latin1_latex (struct recode_outer *);
void delmodule_latin1_bibtex (struct recode_outer *);
void delmodule_latin1_texte (struct recode_outer *);
void delmodule_rfc1345 (struct recode_outer *);
void delmodule_texinfo (struct recode_outer *);
void delmodule_base64 (struct recode_outer *);
void delmodule_dump (struct recode_outer *);
void delmodule_endline (struct recode_outer *);
void delmodule_permutations (struct recode_outer *);
void delmodule_quoted_printable (struct recode_outer *);
void delmodule_ascii_latin1 (struct recode_outer *);
void delmodule_iso5426_latin1 (struct recode_outer *);
void delmodule_ansel_latin1 (struct recode_outer *);
void delmodule_latex_latin1 (struct recode_outer *);
void delmodule_bibtex_latin1 (struct recode_outer *);
void delmodule_texte_latin1 (struct recode_outer *);
